@@ -33,6 +33,7 @@
 #  define KCALENDARCORE_DECL_DEPRECATED_NO_EXPORT KCALENDARCORE_NO_EXPORT KCALENDARCORE_DECL_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef KCALENDARCORE_NO_DEPRECATED
 #    define KCALENDARCORE_NO_DEPRECATED
@@ -84,7 +85,7 @@
 #define KCALENDARCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCALENDARCORE_NO_DEPRECATED
-#  define KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56e00
+#  define KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57400
 #endif
 #ifdef KCALENDARCORE_NO_DEPRECATED_WARNINGS
 #  define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +95,7 @@
 #  ifdef KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0x56e00
+#    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0x57400
 #  endif
 #endif
 
